import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';// this import is used for modules from D3

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

// Formatting total value to display on the line graph
const xAxisTickFormat = number =>
    format('.3s')(number)

const render = data => { 
// giving X axis year data   
  const xValue = d => d.Year; 
  const xAxisLabel = 'Year';
// giving Y axis Tax data 
  const yValue = d => d.Tax;
  const yAxisLabel = 'Tax';
  
  const margin = { top: 10, right: 40, bottom: 88, left: 120 };//mm manière que CSS
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top-30 - margin.bottom-20;
  
  const xScale = scaleTime()
    .domain(extent(data, xValue)) 
    .range([0, innerWidth]) 
    .nice();   
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();// Detrmining the year and Tax 

// giving position the svg element  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`); 
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(20); 
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10) // giving values to x-axis and y-axis
  ;
  	
  
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
//adding a line to svg element by drawing
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
};

// link of the dataset 
csv('https://gist.githubusercontent.com/SharmilaChowdhari/a5adfea11a216ab620304a9a108515bc/raw/93fb56e1429ae9c8d3ece8ef98857cd42be78655/Tax.csv')
  .then(data => {
    data.forEach(d => {
    	d.Tax = +d.Tax;
      d.Year = d3.timeParse("%Y-%m-%d")(d.Year);// year is retrived
    });

    render(data);
  })